@@ -263,4 +263,19 @@ def convert_dict_plotly_fig_png(d):
         if isinstance(d[k], dict):
             convert_dict_plotly_fig_png(d[k])
 
-    return d
\ No newline at end of file
+    return d
+
+
+def jinja_finalize(value):
+    """
+    Finalize for jinja which makes empty entries show as blank rather than none
+    and converts plotly charts to html divs
+    :param value:
+    :return:
+    """
+    if value is None:
+        return ''
+    if isinstance(value, go.Figure):
+        return plhtml(value)
+
+    return value
